package com.yunfeiyun.agmp.fms.service;

import com.yunfeiyun.agmp.fms.domain.FmsSolar;

import java.util.List;
import java.util.Map;


/**
 * 节气时令Service接口
 * 
 * @author 杨晓辉
 * @date 2023-06-01
 */
public interface IFmsSolarService 
{
    /**
     * 查询节气时令
     * 
     * @param solarId 节气时令主键
     * @return 节气时令
     */
    public FmsSolar selectFmsSolarBySolarId(String solarId);
    public FmsSolar selectFmsSolarBySolarName(String solarName);

    /**
     * 查询节气时令列表
     * 
     * @param fmsSolar 节气时令
     * @return 节气时令集合
     */
    public List<FmsSolar> selectFmsSolarList(FmsSolar fmsSolar);

    /**
     * 新增节气时令
     * 
     * @param fmsSolar 节气时令
     * @return 结果
     */
    public int insertFmsSolar(FmsSolar fmsSolar);

    /**
     * 修改节气时令
     * 
     * @param fmsSolar 节气时令
     * @return 结果
     */
    public int updateFmsSolar(FmsSolar fmsSolar);

    /**
     * 批量删除节气时令
     * 
     * @param solarIds 需要删除的节气时令主键集合
     * @return 结果
     */
    public int deleteFmsSolarBySolarIds(String[] solarIds);

    /**
     * 删除节气时令信息
     * 
     * @param solarId 节气时令主键
     * @return 结果
     */
    public int deleteFmsSolarBySolarId(String solarId);

    /**
     * 更新节气时令信息日期
     * */
    public int updateFmsSolarAll();
    /**
     * 查询日期所属节气
     * @param date 日期
     **/
    public FmsSolar getNowSolar(String date);

    public Map<String, Object> getSysZoneByZoneCode(String zoneCode);
}
